==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/message_action_custom_action.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageActionCustomAction(Object):
    """Attributes:
        ID: ``0xfae69f56``

    Parameters:
        message: ``str``
    """

    __slots__ = ["message"]

    ID = 0xfae69f56
    QUALNAME = "types.MessageActionCustomAction"

    def __init__(self, *, message: str):
        self.message = message  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageActionCustomAction":
        # No flags
        
        message = String.read(b)
        
        return MessageActionCustomAction(message=message)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.message))
        
        return b.getvalue()

==> Pyrogram-0.14.1-py3-none-any.whl: pyrogram/api/types/message_action_custom_action.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageActionCustomAction(TLObject):
    """Attributes:
        LAYER: ``100``

    Attributes:
        ID: ``0xfae69f56``

    Parameters:
        message: ``str``
    """

    __slots__ = ["message"]

    ID = 0xfae69f56
    QUALNAME = "types.MessageActionCustomAction"

    def __init__(self, *, message: str):
        self.message = message  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageActionCustomAction":
        # No flags
        
        message = String.read(b)
        
        return MessageActionCustomAction(message=message)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.message))
        
        return b.getvalue()
